#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.2.0.0
visibility:           public
id:                   hls-plugin-api-2.2.0.0-6YWL6LBFpzO4o9geFAjygf
key:                  hls-plugin-api-2.2.0.0-6YWL6LBFpzO4o9geFAjygf
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6dc98bbcb35555e6f70377080e2350cb
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.2.0.0-6YWL6LBFpzO4o9geFAjygf
depends:
    Diff-0.5-9iFzYwbbznxCTrvC5fevGO
    aeson-2.2.1.0-3GuQND0ICGU2GYmExSDp1b base-4.18.2.1
    co-log-core-0.3.2.6-3vrwyvqVYJd1UovIolHFNX containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    dependent-map-0.4.0.1-1hoe9QgIp9l6NGtg7waa59
    dependent-sum-0.7.2.0-AxUBC6fTAvp2mIqhniKxpx
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-6e0wBrlA2xu66mkOtGwbe0 filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    hls-graph-2.2.0.0-I9PWN5GEmjKBAgfSbPrDBw
    hw-fingertree-0.1.2.1-H2lYQVlQQ3T4apkFBC8107
    lens-5.3.3-Ag3JywAjDxJ2k98xBhf4hs
    lens-aeson-1.2.3-9GBZvTcu7cAGonVAnADUb3
    lsp-2.2.0.0-GAelPC2nKQJ3Ee44oBrEuJ
    megaparsec-9.7.0-4yWx9K7i1Xa7WY3KCISRfK mtl-2.3.1
    opentelemetry-0.8.0-4DGPmn5BKVy9ubbkBxiTT0
    optparse-applicative-0.18.1.0-9I3qDpNxi1rBTnWffPMXX3
    prettyprinter-1.7.1-4PNEjQDcFkU8z4wKR8XxHs
    regex-tdfa-1.3.2.5-4Nt33WWCOhH70pmXr5RVz
    row-types-1.0.1.2-1KPI2BY2URnDbZFtTY7TBE stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-2Z0SKAH7tah9jbYwGNfwFX
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

